pub enum ConditionType {
BuiltIn,
Condition,
Weather,
Status,
Type,
Volatile,
ZPower,
}Expand description
The type of a condition.
Variants
BuiltIn
A condition that is built into the battle engine.
Condition
An ordinary condition that can be applied to anything in a battle.
Weather
Weather, which is applied to the entire battlefield.
Status
Status, which is applied to a single Mon for a finite amount of time.
Type
Type, which is applied to a single Mon for a finite amount of time while the user has the type.
Volatile
Volatile, which is applied to a single Mon for a finite amount of time.
ZPower
Z-Power, which is applied to the user of a Z-Move.