pub enum LevelingRate {
Erratic,
Fast,
MediumFast,
MediumSlow,
Slow,
Fluctuating,
}Expand description
Leveling rate, which determines how much experience is required for a species to level up.
Variants
Implementations
Sourceimpl LevelingRate
impl LevelingRate
Sourcepub fn exp_at_level(&self, level: u8) -> u32
pub fn exp_at_level(&self, level: u8) -> u32
The amount of experience a Mon at the given level should have.
Sourcepub fn level_from_exp(&self, exp: u32) -> u8
pub fn level_from_exp(&self, exp: u32) -> u8
Calculates a Mon’s level based on experience points.