MoveFlag

Enum MoveFlag 

pub enum MoveFlag {
Show 47 variants AccuracyLowering, BypassSubstitute, BypassMaxGuard, Bite, Bullet, CallsMove, Charge, Contact, CrashDamage, Dance, Distance, EvasionRaising, FailCopycat, FailEncore, FailInstruct, FailMeFirst, FailMimic, Future, Gravity, Heal, Max, Mirror, MustPressure, NoAssist, NoMetronome, NoParentalBond, NoSketch, NoSleepTalk, OHKO, PledgeCombo, Powder, Protect, Pulse, Punch, Recharge, Reflectable, SleepInducing, SleepUsable, Slicing, Snatch, Sound, Stalling, Thawing, ThawsTarget, WeakenThroughProtection, Wind, Z,
}
Move flags, which categorize moves for miscellaneous behavior (such as bans or side effects).

Variants



AccuracyLowering

Lowers a target’s accuracy.



BypassSubstitute

Bypasses a target’s substitute.



BypassMaxGuard

Bypasses a target’s Max Guard.



Bite

A bite move.



Bullet

A bullet move.



CallsMove

A move that calls another move.



Charge

A charge move, which causes a Mon to be unable to move between turns.



Contact

Makes contact.



CrashDamage

A move with crash damage.



Dance

A dance move.



Distance

Can target a Mon no matter its distance from the user.



EvasionRaising

Raises the user’s evasion.



FailCopycat

Cannot be selected by Copycat.



FailEncore

Cannot be targeted by Encore.



FailInstruct

Cannot be repeated by Instruct.



FailMeFirst

Cannot be selected by Me First.



FailMimic

Cannot be copied by Mimic.



Future

Damages a target in the future.



Gravity

Cannot be used during Gravity’s effect.



Heal

Cannot be used during Heal Block’s effect.



Max

Can be used in Dynamax.



Mirror

Can be copied by Mirror Move.



MustPressure

Additional PP is deducted due to Pressure when it ordinarily would not be.



NoAssist

Cannot be selected by Assist.



NoMetronome

Cannot be used by Metronome.



NoParentalBond

Cannot be made to hit twice via Parental Bond.



NoSketch

Cannot be copied by Sketch.



NoSleepTalk

Cannot be selected by sleep talk.



OHKO

A one-hit KO move.



PledgeCombo

Gems will not activate, and cannot be redirected by Storm Drain or Lightning Rod.



Powder

A powder move.



Protect

Blocked by protection moves.



Pulse

A pulse move.



Punch

A punch move.



Recharge

A move requiring recharge if successful.



Reflectable

A reflectable move.



SleepInducing

A sleep-inducing move.



SleepUsable

A sleep-usable move.



Slicing

A slicing move.



Snatch

Can be stolen from the original user via Snatch.



Sound

A sound move.



Stalling

A stalling move.



Thawing

A thawing move.



ThawsTarget

Thaws the target when hit.



WeakenThroughProtection

Move is weakened when hitting through protection.



Wind

A wind move.



Z

A Z-Move.