pub enum SwitchType {
Normal,
CopyVolatile,
IfHit,
}Expand description
The type of user switch performed when using a move.
Variants
Normal
Normal switch out.
CopyVolatile
Switch out that copies all volatile effects to the replacement Mon.
IfHit
Normal switch out if the move hit.
Implementations