pub struct AbilityData {
pub name: String,
pub flags: HashSet<AbilityFlag>,
pub effect: Value,
pub condition: Value,
}Expand description
Data about a particular ability.
Every Mon has one ability, which affects the battle in a wide variety of ways.
Fields
name: StringName of the ability.
flags: HashSet<AbilityFlag>Ability flags.
effect: ValueDynamic battle effects.
condition: ValueDynamic battle effects of the condition created by this ability.