BoostTable

Struct BoostTable 

pub struct BoostTable {
    pub atk: i8,
    pub def: i8,
    pub spa: i8,
    pub spd: i8,
    pub spe: i8,
    pub acc: i8,
    pub eva: i8,
}
A full boost table.

Fields

atk: i8def: i8spa: i8spd: i8spe: i8acc: i8eva: i8

Implementations

Source

impl BoostTable

pub fn new() -> Self

Creates a new boost table.

pub fn get(&self, boost: Boost) -> i8

Returns the value for the given boost.

pub fn set(&mut self, boost: Boost, value: i8)

Sets the value for the given boost.

pub fn iter<'a>(&'a self) -> impl Iterator<Item = (Boost, i8)> + 'a

Creates an iterator over all entries in the table.

pub fn non_zero_iter<'a>(&'a self) -> impl Iterator<Item = (Boost, i8)> + 'a

Creates an iterator over all non-zero entries in the table.

pub fn values<'a>(&'a self) -> impl Iterator<Item = i8> + 'a

Creates an iterator over all values of the table.