pub struct ConditionData {
pub name: String,
pub condition_type: ConditionType,
pub no_copy: bool,
pub condition: Value,
}Expand description
Data about a particular condition.
Conditions can be applied to Mons as the result of moves or abilities.
Fields
name: StringCondition name.
condition_type: ConditionTypeCondition type.
no_copy: boolCan this condition be copied from one Mon to another?
This relates to how “Baton Pass” affects this condition.
condition: ValueDynamic battle effects.