pub struct EvolutionData {
pub method: EvolutionMethod,
pub condition: String,
pub level: Option<u8>,
pub friendship: Option<bool>,
pub knows_move: Option<String>,
pub time_of_day: Option<String>,
pub holding_item: Option<String>,
pub gender: Option<Gender>,
pub use_item: Option<String>,
pub trade_for: Option<String>,
}Expand description
Details and conditions for one species to evolve into another.
Fields
method: EvolutionMethodThe evolution method, which determines when the rest of the conditions should be checked.
condition: StringA string detailing how the species evolves.
level: Option<u8>Minimum level that must be reached for evolution.
friendship: Option<bool>Does the species require high friendship?
High friendship is defined as a value of at least 220.
knows_move: Option<String>Move that must be present on the Mon’s moveset.
time_of_day: Option<String>Time of day where evolution occurs
holding_item: Option<String>Item held by the Mon.
gender: Option<Gender>Gender of the Mon.
use_item: Option<String>Item that must be used on the Mon.
trade_for: Option<String>The species that this Mon was traded for.