Fraction

Struct Fraction 

pub struct Fraction<I> { /* private fields */ }
A fraction, usable in calculations.

A fraction is serializable as:

  • A fraction string ("1/2").
  • An integer (20), which represents an integer (denominator == 1).
  • A floating point number (1.5), which is converted to a fraction out of 4096.
  • A percentage string ("60%").
  • A two-length array ([2,5]).

Implementations

Source

impl<I> Fraction<I>
where I: FractionInteger,

pub fn new(n: I, d: I) -> Self

Creates a new fraction.

pub fn percentage(n: I) -> Self

Creates a new percentage as a fraction.

pub fn from_f64(value: f64) -> Self

Creates a new fraction from an f64.

Floating point precision is preserved by creating a fraction with a denominator of 4096.

pub fn numerator(&self) -> I

The numerator of the fraction.

pub fn denominator(&self) -> I

The denominator of the fraction.

A flat percentage is always out of 100.

pub fn is_whole(&self) -> bool

Is the fraction whole (i.e., an integer)?

pub fn simplify(&self) -> Self

Simplifies the fraction.

pub fn floor(&self) -> I

Returns the floored integer representation of the fraction.

The integer will be truncated, as if performing integer division.

pub fn ceil(&self) -> I

Returns the ceiled integer representation of the fraction.

pub fn round(&self) -> I
where I: PrimInt,

Returns the rounded integer representation of the fraction.

pub fn convert<T>(self) -> Fraction<T>
where T: FractionInteger + From<I>,

Converts the Fraction<I> to a Fraction<T>, given that T: From<I>.

pub fn try_convert<T>(self) -> Result<Fraction<T>, T::Error>
where T: FractionInteger + TryFrom<I>,

Attempts converting the Fraction<I> to a Fraction<T>, given that T: TryFrom<I>.

pub fn inverse(&self) -> Self

Returns the inverse of this fraction.

Source

impl<I> Fraction<I>

pub fn sqrt(&self) -> Self

pub fn nth_root(&self, n: u32) -> Self

pub fn pow<J>( self, rhs: Fraction<J>, ) -> Result<Self, <J as TryInto<u32>>::Error>
where I: Pow<u32, Output = I> + TryInto<J> + Zero, J: FractionInteger + TryInto<u32> + Signed,