pub struct Id(/* private fields */);Expand description
An ID for a resource.
Resources of the same type should have a unique ID.
A further optimization would be to allocate strings in an arena for memory proximity.
Implementations