ItemData

Struct ItemData 

pub struct ItemData {
    pub name: String,
    pub target: Option<ItemTarget>,
    pub input: Option<ItemInput>,
    pub special_data: SpecialItemData,
    pub force_forme: Option<String>,
    pub flags: HashSet<ItemFlag>,
    pub effect: Value,
    pub condition: Value,
}
Data about a particular item.

Items can be held by a Mon in battle to produce various side effects. Items can affect stat calculations, move calculations, move choice restrictions, and much more.

Fields

name: String

Name of the item.

target: Option<ItemTarget>

Target of the item if used by a player.

input: Option<ItemInput>

Type of input received alongside the item.

special_data: SpecialItemData

Data for special item effects associated with moves and effects.

force_forme: Option<String>

The forme this item forces a Mon into.

flags: HashSet<ItemFlag>

Item flags.

effect: Value

Dynamic battle effects.

condition: Value

Dynamic battle effects of the condition created by this item.