Identifiable

Trait Identifiable 

pub trait Identifiable {
    // Required method
    fn id(&self) -> &Id;
}
A trait that provides a common way of identifying resources.

Resources of the same type should have a unique ID.

Required Methods

fn id(&self) -> &Id

Implementors