Skip to main contentCrate battler_data
Source - AbilityData
- Data about a particular ability.
- BoostOrderIterator
- Iterator type for iterating over
Boosts in a consistent order. - BoostTable
- A full boost table.
- BoostTableEntries
- Iterator type for iterating over non-zero boosts in a
BoostTable (or similar container) in a
stable order. - ClauseData
- Data for an individual clause.
- ConditionData
- Data about a particular condition.
- EventData
- Data for a particular event, which is a special giveaway of some Mon.
- EvolutionData
- Details and conditions for one species to evolve into another.
- FlingData
- Data for what happens when “Fling” is used with this item.
- Fraction
- A fraction, usable in calculations.
- HitEffect
- The effect of being hit by a move.
- Id
- An ID for a resource.
- ItemData
- Data about a particular item.
- JudgmentData
- Data for what happens when “Judgment” is used with this item.
- MaxMoveData
- Data about how a move affects Max Moves.
- MegaEvolutionData
- Data for Mega Evolution.
- MoveData
- Data about a particular move.
- MultiAttackData
- Data for what happens when “Multi-Attack” is used with this item.
- NaturalGiftData
- Data for what happens when “Natural Gift” is used with this item.
- RecoilData
- Data for a move’s recoil damage to the user.
- SecondaryEffectData
- Data about a secondary effect that occurs after a move is used.
- SpecialItemData
- Data for special item effects; namely, item data associated with moves and effects.
- SpeciesData
- Data about a particular species.
- StatTable
- A full stat table.
- StatTableEntries
- Iterator over the entries of a
StatTable. - TechnoBlastData
- Data for what happens when “Techno Blast” is used with this item.
- TypeChart
- A type chart, which contains all type effectiveness information for types against other types
and effects.
- UltraBurstData
- Data for Ultra Burst.
- ZCrystalData
- Data for Z-Crystals.
- ZMoveData
- Data about how a move affects Z-Moves.
- AbilityFlag
- Ability flags, which categorize abilities for miscellaneous behavior (such as bans or side
effects).
- Accuracy
- The base accuracy of a move.
- Boost
- A single stat value that can be boosted.
- ClauseValueType
- The type of a clause value.
- Color
- A defined enumeration of species colors.
- ConditionType
- The type of a condition.
- EvolutionMethod
- Common evolution methods.
- Gender
- The gender of a specific Mon.
- ItemFlag
- Item flags, which categorize items for miscellaneous behavior (such as bans or side
effects).
- ItemInput
- The acceptable target of an item.
- ItemTarget
- The acceptable target of an item.
- LevelingRate
- Leveling rate, which determines how much experience is required for a species to level up.
- MonOverride
- The Mon to use for stat calculations on a move.
- MoveCategory
- The category of a move.
- MoveFlag
- Move flags, which categorize moves for miscellaneous behavior (such as bans or side effects).
- MoveSource
- The source of a move, which details how a species can learn a move in their learnset.
- MoveTarget
- The acceptable target(s) of a move.
- MultihitType
- The number of hits done by a multihit move.
- Nature
- A Mon’s nature, which boosts and drops particular stat values.
- OhkoType
- The type of one-hit KO dealt by the move.
- RecoilBase
- The base number to use for recoil damage calculation.
- Rule
- A single rule that must be validated before a battle starts.
- SelfDestructType
- How the user self destructs after a move.
- ShinyChance
- The chance that a Mon is shiny.
- SpeciesFlag
- Species flags, which categorize species for miscellaneous behavior (such as bans or side
effects).
- Stat
- A single stat value.
- SwitchType
- The type of user switch performed when using a move.
- Type
- The type of a species, which determines its weaknesses and resistances.
- TypeEffectiveness
- Type effectiveness of one type against another.
- ZCrystalSource
- Source of a Z-Crystal’s power.
- ZPower
- Data for the Z-Power of a Z-Move.
- ContainsOptionalBoosts
- Trait for getting a boosted stat from a container.
- DataStore
- Collection of tables for all resource data.
- DataStoreByName
- An extension of
DataStore for looking up resources by name. - FractionInteger
- An integer type that can be used as the inner type of
Fraction. - Identifiable
- A trait that provides a common way of identifying resources.
- deserialize_aliases
- Converts
SerializedAliases into Aliases.
- Aliases
- Map of one ID to another.
- LearnSet
- A species learnset, which maps move names to how they are learned.
- PartialStatTable
- A table of stat values.
- SerializedAliases
- A user-defined set of aliases.
- SerializedRuleSet
- A user-defined set of rules.
- StatMap
- A map of values for each stat.
- TypeTable
- A type table, which contains type effectiveness information for types against some other value.