pub enum MoveTarget {
Show 16 variants
AdjacentAlly,
AdjacentAllyOrUser,
AdjacentFoe,
All,
AllAdjacent,
AllAdjacentFoes,
Allies,
AllySide,
AllyTeam,
Any,
Field,
FoeSide,
Normal,
RandomNormal,
Scripted,
User,
}Expand description
The acceptable target(s) of a move.
In this enum, the following terms are used:
- “Adjacent” = A reachable Mon.
- “Ally” - A Mon on the same side.
- “Foe” - A Mon on the opposite side.
- “Side” - The side of a battle, not any particular Mon on that side.
- “Team” - All unfainted Mons on a team.
- “User” - The user of a move.
Variants
AdjacentAlly
An adjacent ally.
AdjacentAllyOrUser
The user or its ally.
AdjacentFoe
An adjacent foe.
All
All Mons at once.
AllAdjacent
All adjacent mons (including allies).
AllAdjacentFoes
All adjacent foes.
Also known as a spread move.
Allies
All active Mons on the user’s team.
AllySide
The user’s side.
AllyTeam
All unfainted Mons on the user’s team.
Any
Any other active Mon.
Field
The field.
FoeSide
The foe’s side.
Normal
One adjacent Mon of the user’s choice.
Could also be called “Adjacent.”
RandomNormal
Any adjacent foe chosen at random.
Scripted
The for that damaged the user.
User
The user of the move.
Implementations
Sourceimpl MoveTarget
impl MoveTarget
Sourcepub fn requires_target(&self) -> bool
pub fn requires_target(&self) -> bool
Does the move require a single target?
Sourcepub fn has_single_target(&self) -> bool
pub fn has_single_target(&self) -> bool
Does the move have a single target?
Sourcepub fn affects_mons_directly(&self) -> bool
pub fn affects_mons_directly(&self) -> bool
Does the move affect Mons directly?
Sourcepub fn can_target_user(&self) -> bool
pub fn can_target_user(&self) -> bool
Can the move target the user?
Sourcepub fn can_target_foes(&self) -> bool
pub fn can_target_foes(&self) -> bool
Can the move target foes?
Sourcepub fn is_adjacent_only(&self) -> bool
pub fn is_adjacent_only(&self) -> bool
Can the move only target adjacent Mons?
Sourcepub fn valid_target(&self, relative_target: isize, adjacency_reach: u8) -> bool
pub fn valid_target(&self, relative_target: isize, adjacency_reach: u8) -> bool
Validates the relative target position.
Sourcepub fn is_affected(&self, relative_target: isize, adjacency_reach: u8) -> bool
pub fn is_affected(&self, relative_target: isize, adjacency_reach: u8) -> bool
Checks if the Mon at the relative target is affected by the move.