pub enum Rule {
Ban(Id),
Unban(Id),
Value {
name: Id,
value: String,
},
Repeal(Id),
}Expand description
A single rule that must be validated before a battle starts.
Variants
Ban(Id)
Bans something, such as a Mon, item, move, or ability. Serialized as - ID.
Unban(Id)
Unbans something, such as a Mon, item, move, or ability. Serialized as + ID.
An unban is used to override a ban rule that is typically more general. For example, - Legendary, + Giratina would allow the Mon Giratina to be used, even though it is a
legendary.
Value
Some other rule attached to a value. Serialized as name = value.
If value is empty, then the rule is simply serialized as name.
Repeal(Id)
Repeals a previously established rule. Serialized as ! name.
Compound and single rules can be repealed. Bans and unbans cannot be repealed.
Implementations