SwitchType

Enum SwitchType 

pub enum SwitchType {
    Normal,
    CopyVolatile,
    IfHit,
}
The type of user switch performed when using a move.

Variants



Normal

Normal switch out.



CopyVolatile

Switch out that copies all volatile effects to the replacement Mon.



IfHit

Normal switch out if the move hit.

Implementations

Source

impl SwitchType

pub fn if_hit(&self) -> bool

Does the switch depend on hitting the target?