pub struct EventData {
pub level: Option<u8>,
pub shiny: ShinyChance,
pub gender: Option<Gender>,
pub nature: Option<Nature>,
pub ivs: PartialStatTable,
pub hidden_ability: bool,
pub moves: HashSet<String>,
pub ball: Option<String>,
}Expand description
Data for a particular event, which is a special giveaway of some Mon.
Event Mons can have special moves and abilities that the species would not ordinarily have. This data is stored on each species to mark Mons that would ordinarily be illegal as legal and legitimate.
Fields
level: Option<u8>Level Mon was given away at.
shiny: ShinyChanceCan the Mon be shiny?
gender: Option<Gender>Gender.
nature: Option<Nature>Nature.
ivs: PartialStatTableIVs.
Does the Mon have its hidden ability?
moves: HashSet<String>Moves the Mon could have been given away with.
Moves that are ordinarily illegal should be listed here.
ball: Option<String>Type of ball the Mon was given away in.