pub struct Fraction<I> { /* private fields */ }Expand description
A fraction, usable in calculations.
A fraction is serializable as:
- A fraction string (
"1/2"). - An integer (
20), which represents an integer (denominator == 1). - A floating point number (
1.5), which is converted to a fraction out of 4096. - A percentage string (
"60%"). - A two-length array (
[2,5]).
Implementations
Sourceimpl<I> Fraction<I>where
I: FractionInteger,
impl<I> Fraction<I>where
I: FractionInteger,
Sourcepub fn percentage(n: I) -> Self
pub fn percentage(n: I) -> Self
Creates a new percentage as a fraction.
Sourcepub fn from_f64(value: f64) -> Self
pub fn from_f64(value: f64) -> Self
Creates a new fraction from an f64.
Floating point precision is preserved by creating a fraction with a denominator of 4096.
Sourcepub fn denominator(&self) -> I
pub fn denominator(&self) -> I
The denominator of the fraction.
A flat percentage is always out of 100.
Sourcepub fn floor(&self) -> I
pub fn floor(&self) -> I
Returns the floored integer representation of the fraction.
The integer will be truncated, as if performing integer division.
Sourcepub fn round(&self) -> Iwhere
I: PrimInt,
pub fn round(&self) -> Iwhere
I: PrimInt,
Returns the rounded integer representation of the fraction.
Sourcepub fn convert<T>(self) -> Fraction<T>where
T: FractionInteger + From<I>,
pub fn convert<T>(self) -> Fraction<T>where
T: FractionInteger + From<I>,
Converts the Fraction<I> to a Fraction<T>, given that T: From<I>.
Sourcepub fn try_convert<T>(self) -> Result<Fraction<T>, T::Error>where
T: FractionInteger + TryFrom<I>,
pub fn try_convert<T>(self) -> Result<Fraction<T>, T::Error>where
T: FractionInteger + TryFrom<I>,
Attempts converting the Fraction<I> to a Fraction<T>, given that T: TryFrom<I>.
Sourceimpl<I> Fraction<I>where
I: FractionInteger + Roots,
impl<I> Fraction<I>where
I: FractionInteger + Roots,