pub struct MoveData {Show 40 fields
pub name: String,
pub category: MoveCategory,
pub primary_type: Type,
pub base_power: u32,
pub accuracy: Accuracy,
pub pp: u8,
pub priority: i8,
pub target: MoveTarget,
pub flags: HashSet<MoveFlag>,
pub damage: Option<u16>,
pub no_pp_boosts: bool,
pub ohko_type: Option<OhkoType>,
pub user_switch: Option<SwitchType>,
pub self_destruct: Option<SelfDestructType>,
pub recoil: Option<RecoilData>,
pub drain_percent: Option<Fraction<u16>>,
pub typeless: bool,
pub force_stab: bool,
pub hit_effect: Option<HitEffect>,
pub user_effect: Option<HitEffect>,
pub user_effect_chance: Option<Fraction<u16>>,
pub secondary_effects: Vec<SecondaryEffectData>,
pub override_offensive_mon: Option<MonOverride>,
pub override_offensive_stat: Option<Stat>,
pub override_defensive_mon: Option<MonOverride>,
pub override_defensive_stat: Option<Stat>,
pub crit_ratio: Option<u8>,
pub ignore_accuracy: bool,
pub ignore_defensive: bool,
pub ignore_evasion: bool,
pub ignore_offensive: bool,
pub multiaccuracy: bool,
pub multihit: Option<MultihitType>,
pub tracks_target: bool,
pub will_crit: bool,
pub no_random_target: bool,
pub z_move: Option<ZMoveData>,
pub max_move: Option<MaxMoveData>,
pub effect: Value,
pub condition: Value,
}Expand description
Data about a particular move.
Moves are the primary effect that drive battle forward. Every Mon enters a battle with their moveset. Each turn, a Mon uses one move to affect the battle. Moves can damage opposing Mons, affect ally Mons or the user itself, boost or drop stats, apply conditions to Mons or the battlefield itself, and more.
Fields
name: StringName of the move.
category: MoveCategoryMove category.
primary_type: TypeMove type.
base_power: u32Base power.
accuracy: AccuracyBase accuracy.
pp: u8Total power points, which is the number of times this move can be used.
priority: i8Move priority.
target: MoveTargetMove target(s).
flags: HashSet<MoveFlag>Move flags.
damage: Option<u16>Static damage dealt.
no_pp_boosts: boolDisallow PP boosts?
ohko_type: Option<OhkoType>Type of OHKO, if any.
If a target has this type, it is immune.
user_switch: Option<SwitchType>Type of switch that occurs on the user.
self_destruct: Option<SelfDestructType>How the user self destructs.
recoil: Option<RecoilData>Recoil damage to apply.
drain_percent: Option<Fraction<u16>>The percentage of the target’s HP to drain.
typeless: boolTypeless?
force_stab: boolForce STAB?
hit_effect: Option<HitEffect>Primary effect applied to the target.
Applied when the move hits.
user_effect: Option<HitEffect>Primary effect on the user.
Applied when the move hits.
user_effect_chance: Option<Fraction<u16>>Chance of the user effect occurring.
secondary_effects: Vec<SecondaryEffectData>Secondary effects applied to the target.
override_offensive_mon: Option<MonOverride>Mon override for offensive stat calculations.
By default, the move user is used.
override_offensive_stat: Option<Stat>Stat override for offensive stat calculations.
By default, Atk is used for physical moves and SpA is used for special moves.
override_defensive_mon: Option<MonOverride>Mon override for defensive stat calculations.
By default, the move target is used.
override_defensive_stat: Option<Stat>Stat override for defensive stat calculations.
By default, Def is used for physical moves and SpD is used for special moves.
crit_ratio: Option<u8>Critical hit ratio.
ignore_accuracy: boolIgnore accuracy modifiers?
ignore_defensive: boolIgnore defensive modifiers?
ignore_evasion: boolIgnore evasion modifiers?
ignore_offensive: boolIgnore offensive modifiers?
multiaccuracy: boolAccuracy calculations should be run multiple times.
multihit: Option<MultihitType>The move hits multiple times.
tracks_target: boolDoes the move track the target, even if they have moved?
will_crit: boolThe move will always critical hit.
no_random_target: boolDoes the move avoid random targets?
z_move: Option<ZMoveData>Data about how the move affects Z-Moves.
max_move: Option<MaxMoveData>Data about how the move affects Max Moves.
effect: ValueDynamic battle effects.
condition: ValueDynamic battle effects of the condition created by this move.